@@ -109,7 +109,6 @@ sub _menus {
             [ 'overwrite',      "- Overwrite"        ],
             [ 'retries',        "- Download retries" ],
             [ 'timeout',        "- Timeout"          ],
-            [ 'sleep_interval', "- Sleep interval"   ],
         ],
         group_merge => [
             [ 'merge_enabled',   "- Enable Merge"      ],
@@ -362,11 +361,6 @@ sub set_options {
                 my $digits = 3;
                 _opt_number_range( $opt, $choice, $prompt, $digits );
             }
-            elsif ( $choice eq "sleep_interval" ) {
-                my $prompt = 'Seconds to wait between downloads';
-                my $digits = 3;
-                _opt_number_range( $opt, $choice, $prompt, $digits );
-            }
             elsif ( $choice eq "merge_enabled" ) {
                 my $prompt = 'Enable merge';
                 my $list = [ qw( no ask yes ) ];
